aboutsummaryrefslogtreecommitdiff
path: root/pyasn1_modules/rfc5035.py
diff options
context:
space:
mode:
Diffstat (limited to 'pyasn1_modules/rfc5035.py')
-rw-r--r--pyasn1_modules/rfc5035.py19
1 files changed, 10 insertions, 9 deletions
diff --git a/pyasn1_modules/rfc5035.py b/pyasn1_modules/rfc5035.py
index 4a70bb0..1cec982 100644
--- a/pyasn1_modules/rfc5035.py
+++ b/pyasn1_modules/rfc5035.py
@@ -179,20 +179,21 @@ ub_receiptsTo = rfc2634.ub_receiptsTo
ReceiptRequest = rfc2634.ReceiptRequest
-# Map of Attribute Type to the Attribute structure
+# Map of Attribute Type to the Attribute structure is added to the
+# ones that are in rfc5652.py
-ESSAttributeMap = rfc2634.ESSAttributeMap
-
-_ESSAttributeMapAddition = {
+_cmsAttributesMapUpdate = {
id_aa_signingCertificateV2: SigningCertificateV2(),
}
-ESSAttributeMap.update(_ESSAttributeMapAddition)
+rfc5652.cmsAttributesMap.update(_cmsAttributesMapUpdate)
-# Map of Content Type OIDs to Content Types
-# To be added to the ones that are in rfc5652.py
+# Map of Content Type OIDs to Content Types is added to the
+# ones that are in rfc5652.py
-cmsContentTypesMapUpdate = {
+_cmsContentTypesMapUpdate = {
id_ct_receipt: Receipt(),
-} \ No newline at end of file
+}
+
+rfc5652.cmsContentTypesMap.update(_cmsContentTypesMapUpdate)